@@ -19,8 +19,8 @@ func TestVerifyCmd(t *testing.T) {
 		{
 			name: "empty",
 			root: map[string]interface{}{
-				"/home/user": &vfst.Dir{
-					Perm: 0o700,
+				"/home/user/.local/share/chezmoi": &vfst.Dir{
+					Perm: 0o777 &^ chezmoitest.Umask,
 				},
 			},
 		},
